==> eam-wshub-proxyclient-11.4-4-sources.jar: net/datastream/schemas/mp_fields/USERINBOXDETAILS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour USERINBOXDETAILS_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="USERINBOXDETAILS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HOMEUSERID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *         &lt;element name="COUNT" type="{http://www.openapplications.org/oagis_segments}QUANTITY" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "USERINBOXDETAILS_Type", propOrder = {
    "homeuserid",
    "description",
    "count"
})
public class USERINBOXDETAILS_Type {

    @XmlElement(name = "HOMEUSERID", required = true)
    protected HOMEUSERID_Type homeuserid;
    @XmlElement(name = "DESCRIPTION")
    protected String description;
    @XmlElement(name = "COUNT")
    protected QUANTITY count;

    /**
     * Obtient la valeur de la propriété homeuserid.
     * 
     * @return
     *     possible object is
     *     {@link HOMEUSERID_Type }
     *     
     */
    public HOMEUSERID_Type getHOMEUSERID() {
        return homeuserid;
    }

    /**
     * Définit la valeur de la propriété homeuserid.
     * 
     * @param value
     *     allowed object is
     *     {@link HOMEUSERID_Type }
     *     
     */
    public void setHOMEUSERID(HOMEUSERID_Type value) {
        this.homeuserid = value;
    }

    /**
     * Obtient la valeur de la propriété description.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Définit la valeur de la propriété description.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

    /**
     * Obtient la valeur de la propriété count.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getCOUNT() {
        return count;
    }

    /**
     * Définit la valeur de la propriété count.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setCOUNT(QUANTITY value) {
        this.count = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/USERINBOXDETAILS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for USERINBOXDETAILS_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="USERINBOXDETAILS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HOMEUSERID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *         &lt;element name="COUNT" type="{http://www.openapplications.org/oagis_segments}QUANTITY" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "USERINBOXDETAILS_Type", propOrder = {
    "homeuserid",
    "description",
    "count"
})
public class USERINBOXDETAILS_Type {

    @XmlElement(name = "HOMEUSERID", required = true)
    protected HOMEUSERID_Type homeuserid;
    @XmlElement(name = "DESCRIPTION")
    protected String description;
    @XmlElement(name = "COUNT")
    protected QUANTITY count;

    /**
     * Gets the value of the homeuserid property.
     * 
     * @return
     *     possible object is
     *     {@link HOMEUSERID_Type }
     *     
     */
    public HOMEUSERID_Type getHOMEUSERID() {
        return homeuserid;
    }

    /**
     * Sets the value of the homeuserid property.
     * 
     * @param value
     *     allowed object is
     *     {@link HOMEUSERID_Type }
     *     
     */
    public void setHOMEUSERID(HOMEUSERID_Type value) {
        this.homeuserid = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

    /**
     * Gets the value of the count property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getCOUNT() {
        return count;
    }

    /**
     * Sets the value of the count property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setCOUNT(QUANTITY value) {
        this.count = value;
    }

}
